@@ -13,7 +13,7 @@
 #' linear) covariates.
 #' @param smooth.covs A matrix or data frame containing the non-parametric
 #' (i.e., smooth) covariates.
-#' @param familyset (Similar to \code{\link{BiCopSelect}} from the
+#' @param familyset (Similar to \code{\link[VineCopula]{BiCopSelect}} from the
 #' \code{\link[VineCopula:VineCopula-package]{VineCopula}} package)
 #' Vector of bivariate copula families to select from.
 #' If \code{familyset = NA} (default), selection
@@ -34,7 +34,7 @@
 #' are included.
 #' @param familycrit Character indicating the criterion for bivariate copula
 #' selection. Possible choices: \code{familycrit = 'AIC'} (default) or
-#' \code{'BIC'}, as in \code{\link{BiCopSelect}} from the
+#' \code{'BIC'}, as in \code{\link[VineCopula]{BiCopSelect}} from the
 #' \code{\link[VineCopula:VineCopula-package]{VineCopula}} package.
 #' @param level Numerical; significance level of the test for removing individual
 #' predictors (default: \code{level = 0.05}).
@@ -53,7 +53,7 @@
 #' @param verbose \code{TRUE} prints informations during the estimation.
 #' @param select.once if \code{TRUE} the GAM structure is only selected once,
 #'   for the family that appears first in \code{familyset}.
-#' @param ... Additional parameters to be passed to \code{\link{gam}}
+#' @param ... Additional parameters to be passed to \code{\link[mgcv]{gam}}
 #' @return \code{gamBiCopFit} returns a list consisting of
 #' \item{res}{S4 \code{\link{gamBiCop-class}} object.}
 #' \item{method}{\code{'FS'} for Fisher-scoring and
@@ -139,7 +139,7 @@ gamBiCopSelect <- function(udata, lin.covs = NULL, smooth.covs = NULL,
   }
 
   if (length(familyset) == 1 && is.na(familyset)) {
-    familyset <- get.familyset()
+    familyset <- setdiff(get.familyset(), 5)
   }
   if (rotations) {
     familyset <- withRotations(familyset)
